Module common

Module common 

Common data structures shared between requests, responses and events.

Structs

Alignment
Alignment for different items on the scene that is described in two axis. The default is center for both axis.
FontFlags
Different flags for font display that can be combined.

Enums

BlendMode
Different kinds of scene item blend modes.
BoundsType
Different kinds of bounds that can be applied to different items on the scene.
DeinterlaceFieldOrder
Different kinds of input deinterlace field orders.
DeinterlaceMode
Different kinds of input deinterlace modes.
MediaAction
Different kinds of media actions that can be performed (or happen in events).
MonitorType
Monitoring type for audio outputs.