Module source_settings

Module source_settings 

Additional structs for use with crate::client::Inputs::set_settings.

Structs

AvCaptureInputV2
Settings specific to an audio/video input capture source.
AvCaptureInputV2Builder
Use builder syntax to set the inputs and finish with build().
BrowserSource
Settings specific to a browser source.
BrowserSourceBuilder
Use builder syntax to set the inputs and finish with build().
ColorSourceV3
Settings specific to a color source.
ColorSourceV3Builder
Use builder syntax to set the inputs and finish with build().
CoreaudioInputCapture
Settings specific to a CoreAudio input capture source.
CoreaudioInputCaptureBuilder
Use builder syntax to set the inputs and finish with build().
CoreaudioOutputCapture
Settings specific to a CoreAudio output capture source.
CoreaudioOutputCaptureBuilder
Use builder syntax to set the inputs and finish with build().
DisplayCapture
Settings specific to a display capture source.
DisplayCaptureBuilder
Use builder syntax to set the inputs and finish with build().
FfmpegSource
Settings specific to a FFmpeg video source.
FfmpegSourceBuilder
Use builder syntax to set the inputs and finish with build().
Font
Font settings for a TextFt2SourceV2.
FontBuilder
Use builder syntax to set the inputs and finish with build().
FrameRate
Video frame rate of an AvCaptureInputV2.
FrameRateBuilder
Use builder syntax to set the inputs and finish with build().
ImageSource
Settings specific to an image source.
ImageSourceBuilder
Use builder syntax to set the inputs and finish with build().
Resolution
Video resolution for an AvCaptureInputV2.
ResolutionBuilder
Use builder syntax to set the inputs and finish with build().
Slideshow
Settings specific to an image slide-show source.
SlideshowBuilder
Use builder syntax to set the inputs and finish with build().
SlideshowFile
Single file as part of a Slideshow.
SlideshowFileBuilder
Use builder syntax to set the inputs and finish with build().
TextFt2SourceV2
Settings specific to a FreeType2 text source.
TextFt2SourceV2Builder
Use builder syntax to set the inputs and finish with build().
VlcSource
Settings specific to a VLC video source.
VlcSourceBuilder
Use builder syntax to set the inputs and finish with build().
WindowCapture
Settings specific to a window capture source.
WindowCaptureBuilder
Use builder syntax to set the inputs and finish with build().

Enums

AvPreset
Different presets for the AvCaptureInputV2.
ColorRange
YUV color range of a FfmpegSource.
ColorSpace
Color space as part of an AvCaptureInputV2.
CropMode
The capture cropping for a DisplayCapture source.
CustomSize
Aspect ratios and bounding sizes for use in Slideshow.
PlaybackBehavior
Playback behavior setting for use in Slideshow.
SlideMode
Playback control mode for use in Slideshow.
Transition
Transition animation between images in a Slideshow.
VideoRange
Video color range as part of an AvCaptureInputV2.

Constants

SOURCE_AV_CAPTURE_INPUT_V2
Identifier for audio/video input capture sources.
SOURCE_BROWSER_SOURCE
Identifier for browser sources.
SOURCE_COLOR_SOURCE_V3
Identifier for color sources.
SOURCE_COREAUDIO_INPUT_CAPTURE
Identifier for input capture sources.
SOURCE_COREAUDIO_OUTPUT_CAPTURE
Identifier for output capture sources.
SOURCE_DISPLAY_CAPTURE
Identifier for display capture sources.
SOURCE_FFMPEG_SOURCE
Identifier for FFmpeg video sources.
SOURCE_IMAGE_SOURCE
Identifier for image sources.
SOURCE_SLIDESHOW
Identifier for image slide-show sources.
SOURCE_TEXT_FT2_SOURCE_V2
Identifier for FreeType2 text sources.
SOURCE_VLC_SOURCE
Identifier for VLC video sources.
SOURCE_WINDOW_CAPTURE
Identifier for source window capture sources.