#[non_exhaustive]pub enum Transition {
Cut,
Fade,
Swipe,
Slide,
}Expand description
Transition animation between images in a Slideshow.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Cut
Immediately replace without animation.
Fade
Gradually fade between the two images until the new one is fully visible.
Swipe
Swipe the new image over the old one.
Slide
Slide out the old and slide in the new image.