TextFt2SourceV2

Struct TextFt2SourceV2 

pub struct TextFt2SourceV2<'a> {
Show 13 fields pub antialiasing: bool, pub color1: RGBA8, pub color2: RGBA8, pub custom_width: u32, pub drop_shadow: bool, pub font: Font<'a>, pub from_file: bool, pub log_lines: u32, pub log_mode: bool, pub outline: bool, pub text: &'a str, pub text_file: &'a Path, pub word_wrap: bool,
}
Settings specific to a FreeType2 text source.

Fields

antialiasing: bool

Draw the text with smoothed corners.

color1: RGBA8

Top color of the text.

color2: RGBA8

Bottom color of the text.

custom_width: u32

Custom width (seems to have no effect).

drop_shadow: bool

Draw a dark blurred shadow effect behind the text.

font: Font<'a>

Settings for the font.

from_file: bool

Load the text from a file (must be set in combination with Self::text_file).

log_lines: u32

Amount of log lines if Self::log_mode is true. Minimum value is 1.

log_mode: bool

Log mode (not sure what this does).

outline: bool

Draw a black border around the text corners.

text: &'a str

Text to display (only used if Self::from_file is false).

text_file: &'a Path

File to load the display text from (Self::from_file must be true). The content must be in either UTF-8 or UTF-16 encoding.

word_wrap: bool

Wrap the words within the boundaries of the scene item.

Implementations

Source

impl<'a> TextFt2SourceV2<'a>

pub fn builder() -> TextFt2SourceV2Builder<'a>

Create an instance of TextFt2SourceV2 using the builder syntax