Create

Struct Create 

pub struct Create<'a, T> {
    pub source: SourceId<'a>,
    pub filter: &'a str,
    pub kind: &'a str,
    pub settings: Option<T>,
}
Request information for crate::client::Filters::create.

Fields

source: SourceId<'a>

Identifier of the source to add the filter to.

filter: &'a str

Name of the new filter to be created.

kind: &'a str

The kind of filter to be created.

settings: Option<T>

Settings object to initialize the filter with.

Implementations

Source

impl<'a, T> Create<'a, T>

pub fn builder() -> CreateBuilder<'a, T>

Create an instance of Create using the builder syntax