SceneItemTransform

Struct SceneItemTransform 

pub struct SceneItemTransform {
    pub position: Option<Position>,
    pub rotation: Option<f32>,
    pub scale: Option<Scale>,
    pub alignment: Option<Alignment>,
    pub bounds: Option<Bounds>,
    pub crop: Option<Crop>,
}
Request information for crate::client::SceneItems::set_transform as part of SetTransform.

Fields

position: Option<Position>

Position (or offset) on the screen.

rotation: Option<f32>

The clockwise rotation of the scene item in degrees around the point of alignment.

scale: Option<Scale>

Scaling of the item.

alignment: Option<Alignment>

The point on the source that the item is manipulated from.

bounds: Option<Bounds>

Bound restrictions on the item.

crop: Option<Crop>

Cropping values on up to 4 sides.

Implementations

Source

impl SceneItemTransform

pub fn builder() -> SceneItemTransformBuilder

Create an instance of SceneItemTransform using the builder syntax