Common data structures shared between requests, responses and events.
Structs
- Alignment
- Alignment for different items on the scene that is described in two axis. The default is center for both axis.
- Font
Flags - Different flags for font display that can be combined.
Enums
- Blend
Mode - Different kinds of scene item blend modes.
- Bounds
Type - Different kinds of bounds that can be applied to different items on the scene.
- Deinterlace
Field Order - Different kinds of input deinterlace field orders.
- Deinterlace
Mode - Different kinds of input deinterlace modes.
- Media
Action - Different kinds of media actions that can be performed (or happen in events).
- Monitor
Type - Monitoring type for audio outputs.