pub struct OutputFlags(/* private fields */);events only.Expand description
These flags determine what type of data the source outputs and expects.
Implementations
Sourceimpl OutputFlags
impl OutputFlags
Sourcepub const VIDEO: Self
pub const VIDEO: Self
Source has video.
Unless SOURCE_ASYNC_VIDEO is specified, the source must include the video_render callback in the source definition structure.
Sourcepub const AUDIO: Self
pub const AUDIO: Self
Source has audio.
Use the obs_source_output_audio function to pass raw audio data, which will be automatically converted and uploaded. If used with SOURCE_ASYNC_VIDEO, audio will automatically be synced up to the video output.
Sourcepub const ASYNC: Self
pub const ASYNC: Self
Async video flag (use Self::ASYNC_VIDEO).
Sourcepub const ASYNC_VIDEO: Self
pub const ASYNC_VIDEO: Self
Source passes raw video data via RAM.
Use the obs_source_output_video function to pass raw video data, which will be automatically uploaded at the specified timestamp.
If this flag is specified, it is not necessary to include the video_render callback. However, if you wish to use that function as well, you must call obs_source_getframe to get the current frame data, and obs_source_releaseframe to release the data when complete.
Sourcepub const CUSTOM_DRAW: Self
pub const CUSTOM_DRAW: Self
Source uses custom drawing, rather than a default effect.
If this flag is specified, the video_render callback will pass a NULL effect, and effect-based filters will not use direct rendering.
Sourcepub const INTERACTION: Self
pub const INTERACTION: Self
Source supports interaction.
When this is used, the source will receive interaction events if they provide the necessary callbacks in the source definition structure.
Sourcepub const COMPOSITE: Self
pub const COMPOSITE: Self
Source composites sub-sources
When used specifies that the source composites one or more sub-sources. Sources that render sub-sources must implement the audio_render callback in order to perform custom mixing of sub-sources.
This capability flag is always set for transitions.
Sourcepub const DO_NOT_DUPLICATE: Self
pub const DO_NOT_DUPLICATE: Self
Source should not be fully duplicated
When this is used, specifies that the source should not be fully duplicated, and should prefer to duplicate via holding references rather than full duplication.
Sourcepub const DEPRECATED: Self
pub const DEPRECATED: Self
Source is deprecated and should not be used.
Sourcepub const DO_NOT_SELF_MONITOR: Self
pub const DO_NOT_SELF_MONITOR: Self
Source cannot have its audio monitored
Specifies that this source may cause a feedback loop if audio is monitored with a device selected as desktop audio.
This is used primarily with desktop audio capture sources.
Sourcepub const CAP_DISABLED: Self
pub const CAP_DISABLED: Self
Source type is currently disabled and should not be shown to the user.
Sourcepub const CAP_OBSOLETE: Self
pub const CAP_OBSOLETE: Self
Source type is obsolete (has been updated with new defaults/properties/etc).
Sourcepub const MONITOR_BY_DEFAULT: Self
pub const MONITOR_BY_DEFAULT: Self
Source should enable monitoring by default. Monitoring should be set by the frontend if this flag is set.
Sourcepub const CONTROLLABLE_MEDIA: Self
pub const CONTROLLABLE_MEDIA: Self
Source type can be controlled by media controls.
Sourcepub const CAP_DONT_SHOW_PROPERTIES: Self
pub const CAP_DONT_SHOW_PROPERTIES: Self
Source type prefers not to have its properties shown on creation (prefers to rely on defaults first).
Sourcepub const REQUIRES_CANVAS: Self
pub const REQUIRES_CANVAS: Self
Source requires a canvas to operate.
Sourceimpl OutputFlags
impl OutputFlags
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl OutputFlags
impl OutputFlags
Sourcepub const fn iter(&self) -> Iter<OutputFlags>
pub const fn iter(&self) -> Iter<OutputFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<OutputFlags>
pub const fn iter_names(&self) -> IterNames<OutputFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.