Additional structs for use with
crate::client::Inputs::set_settings.
Structs
- AvCapture
Input V2 - Settings specific to an audio/video input capture source.
- AvCapture
Input V2Builder - Use builder syntax to set the inputs and finish with
build(). - Browser
Source - Settings specific to a browser source.
- Browser
Source Builder - Use builder syntax to set the inputs and finish with
build(). - Color
Source V3 - Settings specific to a color source.
- Color
Source V3Builder - Use builder syntax to set the inputs and finish with
build(). - Coreaudio
Input Capture - Settings specific to a
CoreAudioinput capture source. - Coreaudio
Input Capture Builder - Use builder syntax to set the inputs and finish with
build(). - Coreaudio
Output Capture - Settings specific to a
CoreAudiooutput capture source. - Coreaudio
Output Capture Builder - Use builder syntax to set the inputs and finish with
build(). - Display
Capture - Settings specific to a display capture source.
- Display
Capture Builder - Use builder syntax to set the inputs and finish with
build(). - Ffmpeg
Source - Settings specific to a
FFmpegvideo source. - Ffmpeg
Source Builder - Use builder syntax to set the inputs and finish with
build(). - Font
- Font settings for a
TextFt2SourceV2. - Font
Builder - Use builder syntax to set the inputs and finish with
build(). - Frame
Rate - Video frame rate of an
AvCaptureInputV2. - Frame
Rate Builder - Use builder syntax to set the inputs and finish with
build(). - Image
Source - Settings specific to an image source.
- Image
Source Builder - Use builder syntax to set the inputs and finish with
build(). - Resolution
- Video resolution for an
AvCaptureInputV2. - Resolution
Builder - Use builder syntax to set the inputs and finish with
build(). - Slideshow
- Settings specific to an image slide-show source.
- Slideshow
Builder - Use builder syntax to set the inputs and finish with
build(). - Slideshow
File - Single file as part of a
Slideshow. - Slideshow
File Builder - Use builder syntax to set the inputs and finish with
build(). - Text
Ft2Source V2 - Settings specific to a
FreeType2text source. - Text
Ft2Source V2Builder - Use builder syntax to set the inputs and finish with
build(). - VlcSource
- Settings specific to a VLC video source.
- VlcSource
Builder - Use builder syntax to set the inputs and finish with
build(). - Window
Capture - Settings specific to a window capture source.
- Window
Capture Builder - Use builder syntax to set the inputs and finish with
build().
Enums
- AvPreset
- Different presets for the
AvCaptureInputV2. - Color
Range - YUV color range of a
FfmpegSource. - Color
Space - Color space as part of an
AvCaptureInputV2. - Crop
Mode - The capture cropping for a
DisplayCapturesource. - Custom
Size - Aspect ratios and bounding sizes for use in
Slideshow. - Playback
Behavior - Playback behavior setting for use in
Slideshow. - Slide
Mode - Playback control mode for use in
Slideshow. - Transition
- Transition animation between images in a
Slideshow. - Video
Range - Video color range as part of an
AvCaptureInputV2.
Constants
- SOURCE_
AV_ CAPTURE_ INPUT_ V2 - Identifier for audio/video input capture sources.
- SOURCE_
BROWSER_ SOURCE - Identifier for browser sources.
- SOURCE_
COLOR_ SOURCE_ V3 - Identifier for color sources.
- SOURCE_
COREAUDIO_ INPUT_ CAPTURE - Identifier for input capture sources.
- SOURCE_
COREAUDIO_ OUTPUT_ CAPTURE - Identifier for output capture sources.
- SOURCE_
DISPLAY_ CAPTURE - Identifier for display capture sources.
- SOURCE_
FFMPEG_ SOURCE - Identifier for
FFmpegvideo sources. - SOURCE_
IMAGE_ SOURCE - Identifier for image sources.
- SOURCE_
SLIDESHOW - Identifier for image slide-show sources.
- SOURCE_
TEXT_ FT2_ SOURCE_ V2 - Identifier for
FreeType2text sources. - SOURCE_
VLC_ SOURCE - Identifier for VLC video sources.
- SOURCE_
WINDOW_ CAPTURE - Identifier for source window capture sources.