pub struct TextFt2SourceV2<'a> {}Expand description
Settings specific to a FreeType2 text source.
Fields
antialiasing: boolDraw the text with smoothed corners.
color1: RGBA8Top color of the text.
color2: RGBA8Bottom color of the text.
custom_width: u32Custom width (seems to have no effect).
drop_shadow: boolDraw a dark blurred shadow effect behind the text.
font: Font<'a>Settings for the font.
from_file: boolLoad the text from a file (must be set in combination with Self::text_file).
log_lines: u32Amount of log lines if Self::log_mode is true. Minimum value is 1.
log_mode: boolLog mode (not sure what this does).
outline: boolDraw a black border around the text corners.
text: &'a strText to display (only used if Self::from_file is false).
text_file: &'a PathFile to load the display text from (Self::from_file must be true). The
content must be in either UTF-8 or UTF-16 encoding.
word_wrap: boolWrap the words within the boundaries of the scene item.
Implementations
Sourceimpl<'a> TextFt2SourceV2<'a>
impl<'a> TextFt2SourceV2<'a>
Sourcepub fn builder() -> TextFt2SourceV2Builder<'a>
pub fn builder() -> TextFt2SourceV2Builder<'a>
Create an instance of TextFt2SourceV2 using the builder syntax